# coastal-dynamics

## Description
The coastal-dynamics package was developed at Delft University of Technology by the Coastal Dynamics teaching team as an educational tool to facilitate an online and open source educational suite. For more information, see the [GitHub organization](https://github.com/Coastal-Dynamics) of the Coastal Dynamics teaching team.

## Installation
To install the coastal-dynamics package from PyPI, run 'pip install coastal_dynamics'.

## Usage
We use the coastal-dynamics package to generate interactive python widgets from question data. So far, we have implemented standardized formats for multiple choice, multiple selection, numeric, and text questions.

Given answers are automatically hashed and compared to the hashed answers in the question data.

For examples of implementation, we invite you to look at the [CoastalCodebook repository](https://github.com/Coastal-Dynamics/CoastalCodebook) on GitHub.

## Contributors

We welcome and recognize all contributions. You can see a list of current contributors in
the [contributors
tab](https://github.com/Coastal-Dynamics/coastal-dynamics/graphs/contributors).
